@@ -92,9 +92,9 @@ The elements of the list. This is the internally used array, but it can be manip
 
 Creates a new C<ByteList> object using L</"new_len">.
 
-The passed length to L</"new_len"> is the length of the C<$array>. If the array is C<undef>, the length is C<0>.
+The passed length to L</"new_len"> is the length of the $array. If the array is C<undef>, the length is C<0>.
 
-The elements of the C<$array> are copied to the values of the the created array.
+The elements of the $array are copied to the values of the the created array.
 
 Examples:
 
@@ -105,15 +105,15 @@ Examples:
 
   static method new_len : ByteList ($length : int, $capacity = -1 : int);
 
-Creates a new C<ByteList> object with the C<$length> and the C<$capacity>.
+Creates a new C<ByteList> object with the $length and the $capacity.
 
-If the C<$capacity> is less than C<0>, the capacity is set to the value of L</"DEFAULT_CAPACITY">.
+If the $capacity is less than C<0>, the capacity is set to the value of L</"DEFAULT_CAPACITY">.
 
-If the C<$length> is greater than the C<$capacity>, the C<$capacity> is set to the C<$length>.
+If the $length is greater than the $capacity, the $capacity is set to the $length.
 
 Exceptions:
 
-The C<$length> must be greater than or equal to C<0>.
+The $length must be greater than or equal to C<0>.
 
 =head1 Instance Methods
 
@@ -121,25 +121,25 @@ The C<$length> must be greater than or equal to C<0>.
 
   method get : int ($index : int);
 
-Gets the element of the position of the C<$index>.
+Gets the element of the position of the $index.
 
 Exceptions:
 
-The C<$index> must be greater than or equal to 0.
+The $index must be greater than or equal to 0.
 
-The C<$index> must be less than the length of the C<$list>.
+The $index must be less than the length of the $list.
 
 =head2 insert
 
   method insert : void ($index : int, $element : int);
 
-Inserts an C<$element> to the position of the C<$index>.
+Inserts an $element to the position of the $index.
 
 Exceptions:
 
-The C<$index> must be greater than or equal to C<0>.
+The $index must be greater than or equal to C<0>.
 
-The C<$index> must be less than or equal to the length of the C<$list>.
+The $index must be less than or equal to the length of the $list.
 
 =head2 pop
 
@@ -149,87 +149,87 @@ Removes the last element and return it.
 
 Exceptions:
 
-The length of the C<$list> must be greater than C<0>.
+The length of the $list must be greater than C<0>.
 
 =head2 push
   
   method push : void ($element : int);
 
-Adds an C<$element> after the end of the list.
+Adds an $element after the end of the list.
 
 =head2 remove
 
   method remove : int ($index : int);
 
-Removes the element at the position of the C<$index> and return it.
+Removes the element at the position of the $index and return it.
 
 Exceptions:
 
-The C<$index> must be greater than or equal to C<0>.
+The $index must be greater than or equal to C<0>.
 
-The C<$index> must be less than the length of the C<$list>.
+The $index must be less than the length of the $list.
 
 =head2 replace
 
   method replace : void ($offset : int, $remove_length : int, $replace : byte[]);
 
-Replaces the elements of the range specified by the C<$offset> and the C<$lenght> with the C<$replace> array.
+Replaces the elements of the range specified by the $offset and the $lenght with the $replace array.
 
 Exceptions:
 
-The C<$offset> must be greater than or equal to C<0>.
+The $offset must be greater than or equal to C<0>.
 
-The C<$remove_length> must be greater than or equal to C<0>.
+The $remove_length must be greater than or equal to C<0>.
 
-The C<$offset> + the C<$removing> lenght must be less than or equal to the length of the C<$list>.
+The $offset + the $removing lenght must be less than or equal to the length of the $list.
 
 =head2 reserve
 
   method reserve : void ($new_capacity : int);
 
-Reserves the elements with the C<$new_capacity>.
+Reserves the elements with the $new_capacity.
 
-If the C<$new_capacity> is greater than the capacity of the list, the capacity of the list is extended to the C<$new_capacity>.
+If the $new_capacity is greater than the capacity of the list, the capacity of the list is extended to the $new_capacity.
 
 Note that L</"values"> is replaced with the new values and the values of the original list are copied to the new values in the above case.
 
 Exceptions:
 
-The C<$new_capacity> must be greater than or equal to C<0>.
+The $new_capacity must be greater than or equal to C<0>.
 
 =head2 resize
 
   method resize : void ($new_length : int);
 
-Resizes the list with the C<$new_length>.
+Resizes the list with the $new_length.
 
 Exceptions:
 
-The C<$new_length> must be greater than or equal to C<0>.
+The $new_length must be greater than or equal to C<0>.
 
 =head2 set
 
   method set : void ($index : int, $element : int);
 
-Sets the C<$element> at the position of the C<$index>.
+Sets the $element at the position of the $index.
 
 Exceptions:
 
-The C<$index> must be greater than or equal to C<0>.
+The $index must be greater than or equal to C<0>.
 
-The C<$index> must be less than the length of the C<$list>.
+The $index must be less than the length of the $list.
 
 =head2 set_array
 
   method set_array : void ($array : byte[]);
 
-Sets an C<$array>. Each element of the C<$array> is copied to the element of the list.
+Sets an $array. Each element of the $array is copied to the element of the list.
 
 Exceptions:
 
-The C<$array> must be defined.
+The $array must be defined.
 
-The length of the C<$array> must be the C<$same> as the length of the C<$list>.
+The length of the $array must be the $same as the length of the $list.
 
 =head2 shift
 
@@ -239,7 +239,7 @@ Removes the first element and return it.
 
 Exceptions:
 
-The length of the C<$list> must be greater than C<0>.
+The length of the $list must be greater than C<0>.
 
 =head2 to_array
 
@@ -251,4 +251,4 @@ Converts the list to an array.
 
   method unshift : void ($element : int);
 
-Inserts an C<$element> at the beginning of the list.
+Inserts an $element at the beginning of the list.
