@@ -35,8 +35,6 @@ C<Point> class has the following interfaces.
 
 =item * L<Cloneable|SPVM::Cloneable>
 
-=item * L<Cloneable|SPVM::Point::Interface>
-
 =back
 
 =head1 Fields
@@ -69,12 +67,6 @@ Create a new C<Point> object with $x and $y.
 
 Initializes L</"x"> and L</"y">.
 
-=head2 has_interfaces
-
-  method has_interfaces : int ();
-
-Returns C<1>.
-
 =head2 clear
 
   method clear : void ();
